==> xcfa_4.0.0.orig.tar.gz: xcfa-4.0.0/src/play_file.c <==
 /*
 * file      : play_file.c
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */



#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <stdlib.h>
#include <sys/types.h>
#include <unistd.h>
#include <string.h>
#include <pthread.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib/lib.h"
#endif

#include "global.h"
#include "extra.h"
#include "win_info.h"
#include "play_file.h"


typedef struct {
	pthread_t	 nmr_tid;
	gchar		*Playeur;
	gchar		*Param;
	gchar		*PathNameFile;
} VAR_PLAYFILE ;

VAR_PLAYFILE PlayFile;


void PlayFile_call (void)
{
	pid_t  pid;

	if ((pid = fork ()) == 0) {
		if (NULL != PlayFile.Param && '\0' != *PlayFile.Param) {
			execlp (PlayFile.Playeur,
				PlayFile.Playeur,
				PlayFile.Param,
				PlayFile.PathNameFile,
				NULL);
			_exit (0);
		}
		else {
			execlp (PlayFile.Playeur,
				PlayFile.Playeur,
				PlayFile.PathNameFile,
				NULL);
			_exit (0);
		}
	}
}

static void PlayFile_thread (void *arg)
{
	PlayFile_call ();
	pthread_exit(0);
}

void PlayFile_play (gchar *PathNameFile)
{
	PRINT_FUNC_LF();
	g_print ("\t%s\n", PathNameFile);
	
	if (FALSE == extra_get_lecteur_audio_is_ok ()) {
		PRINT("VEUILLEZ SAISIR UN LECTEUR AUDIO");
		wininfo_create (
			_("PAS de lecteur audio present"),
			_("Veuillez installez un lecteur audio."),
			  "");
		return;
	}
	
	if (PlayFile.Playeur != NULL) {
		g_free (PlayFile.Playeur);	PlayFile.Playeur = NULL;
	}
	if (PlayFile.Param != NULL) {
		g_free (PlayFile.Param);	PlayFile.Param = NULL;
	}
	if (PlayFile.PathNameFile != NULL) {
		g_free (PlayFile.PathNameFile);	PlayFile.PathNameFile = NULL;
	}
	
	PlayFile.Playeur      = g_strdup (extra_get_name_lecteur_audio ());
	PlayFile.Param        = g_strdup (extra_get_param_name_lecteur_audio ());
	PlayFile.PathNameFile = g_strdup (PathNameFile);
	pthread_create (&PlayFile.nmr_tid, NULL ,(void *)PlayFile_thread, (void *)NULL);
}

==> xcfa_4.0.3.orig.tar.gz: xcfa-4.0.3/src/play_file.c <==
 /*
 * file      : play_file.c
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2011 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */



#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <stdlib.h>
#include <sys/types.h>
#include <unistd.h>
#include <string.h>
#include <pthread.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib/lib.h"
#endif

#include "global.h"
#include "extra.h"
#include "win_info.h"
#include "play_file.h"


typedef struct {
	pthread_t	 nmr_tid;
	gchar		*Playeur;
	gchar		*Param;
	gchar		*PathNameFile;
} VAR_PLAYFILE ;

VAR_PLAYFILE PlayFile;


void PlayFile_call (void)
{
	pid_t  pid;

	if ((pid = fork ()) == 0) {
		if (NULL != PlayFile.Param && '\0' != *PlayFile.Param) {
			execlp (PlayFile.Playeur,
				PlayFile.Playeur,
				PlayFile.Param,
				PlayFile.PathNameFile,
				NULL);
		}
		else {
			execlp (PlayFile.Playeur,
				PlayFile.Playeur,
				PlayFile.PathNameFile,
				NULL);
		}
		_exit (0);
	}
}

static void PlayFile_thread (void *arg)
{
	PlayFile_call ();
	pthread_exit(0);
}

void PlayFile_play (gchar *PathNameFile)
{
	PRINT_FUNC_LF();
	
	if (FALSE == extra_get_lecteur_audio_is_ok ()) {
		PRINT("VEUILLEZ SAISIR UN LECTEUR AUDIO");
		wininfo_create (
			_("PAS de lecteur audio present"),
			_("Veuillez installez un lecteur audio."),
			  "");
		return;
	}
	
	if (PlayFile.Playeur != NULL) {
		g_free (PlayFile.Playeur);	PlayFile.Playeur = NULL;
	}
	if (PlayFile.Param != NULL) {
		g_free (PlayFile.Param);	PlayFile.Param = NULL;
	}
	if (PlayFile.PathNameFile != NULL) {
		g_free (PlayFile.PathNameFile);	PlayFile.PathNameFile = NULL;
	}
	
	PlayFile.Playeur      = g_strdup (extra_get_name_lecteur_audio ());
	PlayFile.Param        = g_strdup (extra_get_param_name_lecteur_audio ());
	PlayFile.PathNameFile = g_strdup (PathNameFile);
	g_print ("\tFILE    : %s\n", PathNameFile);
	g_print ("\tPLAYEUR : %s\n", PlayFile.Playeur);
	g_print ("\tPARAM   : %s\n", PlayFile.Param);
	pthread_create (&PlayFile.nmr_tid, NULL ,(void *)PlayFile_thread, (void *)NULL);
}
